Struct ExtWorkspaceManagerV1
pub struct ExtWorkspaceManagerV1 { /* private fields */ }wayland and Linux only.Expand description
list and control workspaces
Workspaces, also called virtual desktops, are groups of surfaces. A compositor with a concept of workspaces may only show some such groups of surfaces (those of ‘active’ workspaces) at a time. ‘Activating’ a workspace is a request for the compositor to display that workspace’s surfaces as normal, whereas the compositor may hide or otherwise de-emphasise surfaces that are associated only with ‘inactive’ workspaces. Workspaces are grouped by which sets of outputs they correspond to, and may contain surfaces only from those outputs. In this way, it is possible for each output to have its own set of workspaces, or for all outputs (or any other arbitrary grouping) to share workspaces. Compositors may optionally conceptually arrange each group of workspaces in an N-dimensional grid.
The purpose of this protocol is to enable the creation of taskbars and docks by providing them with a list of workspaces and their properties, and allowing them to activate and deactivate workspaces.
After a client binds the ext_workspace_manager_v1, each workspace will be sent via the workspace event.
See also the Event enum for this interface.
Implementations
impl ExtWorkspaceManagerV1
impl ExtWorkspaceManagerV1
pub fn commit(&self)
pub fn commit(&self)
all requests about the workspaces have been sent
The client must send this request after it has finished sending other requests. The compositor must process a series of requests preceding a commit request atomically.
This allows changes to the workspace properties to be seen as atomic, even if they happen via multiple events, and even if they involve multiple ext_workspace_handle_v1 objects, for example, deactivating one workspace and activating another.
pub fn stop(&self)
pub fn stop(&self)
stop sending events
Indicates the client no longer wishes to receive events for new workspace groups. However the compositor may emit further workspace events, until the finished event is emitted. The compositor is expected to send the finished event eventually once the stop request has been processed.
The client must not send any requests after this one, doing so will raise a wl_display invalid_object error.